@@ -29,7 +29,7 @@ class PyWebHdfsClient(object):
         self.port = port
         self.user_name = user_name
 
-        #create base uri to be used in request operations
+        # create base uri to be used in request operations
         self.base_uri = 'http://{host}:{port}/webhdfs/v1/'.format(
             host=self.host, port=self.port)
 
@@ -71,25 +71,25 @@ class PyWebHdfsClient(object):
         WebHDFS documentation
         """
 
-        #make the initial CREATE call to the HDFS namenode
+        # make the initial CREATE call to the HDFS namenode
         optional_args = kwargs
         uri = self._create_uri(path, operations.CREATE, **optional_args)
         init_response = requests.put(uri, allow_redirects=False)
 
         if not init_response.status_code == httplib.TEMPORARY_REDIRECT:
             _raise_pywebhdfs_exception(
-                init_response.status_code, init_response.text)
+                init_response.status_code, init_response.content)
 
-        #Get the address provided in the location header of the
+        # Get the address provided in the location header of the
         # initial response from the namenode and make the CREATE request
-        #to the datanode
+        # to the datanode
         uri = init_response.headers['location']
         response = requests.put(
             uri, data=file_data,
             headers={'content-type': 'application/octet-stream'})
 
         if not response.status_code == httplib.CREATED:
-            _raise_pywebhdfs_exception(response.status_code, response.text)
+            _raise_pywebhdfs_exception(response.status_code, response.content)
 
         return True
 
@@ -126,25 +126,25 @@ class PyWebHdfsClient(object):
         Append is not supported in Hadoop 1.x
         """
 
-        #make the initial APPEND call to the HDFS namenode
+        # make the initial APPEND call to the HDFS namenode
         optional_args = kwargs
         uri = self._create_uri(path, operations.APPEND, **optional_args)
         init_response = requests.post(uri, allow_redirects=False)
 
         if not init_response.status_code == httplib.TEMPORARY_REDIRECT:
             _raise_pywebhdfs_exception(
-                init_response.status_code, init_response.text)
+                init_response.status_code, init_response.content)
 
-        #Get the address provided in the location header of the
+        # Get the address provided in the location header of the
         # initial response from the namenode and make the APPEND request
-        #to the datanode
+        # to the datanode
         uri = init_response.headers['location']
         response = requests.post(
             uri, data=file_data,
             headers={'content-type': 'application/octet-stream'})
 
         if not response.status_code == httplib.OK:
-            _raise_pywebhdfs_exception(response.status_code, response.text)
+            _raise_pywebhdfs_exception(response.status_code, response.content)
 
         return True
 
@@ -179,9 +179,9 @@ class PyWebHdfsClient(object):
         response = requests.get(uri, allow_redirects=True)
 
         if not response.status_code == httplib.OK:
-            _raise_pywebhdfs_exception(response.status_code, response.text)
+            _raise_pywebhdfs_exception(response.status_code, response.content)
 
-        return response.text
+        return response.content
 
     def make_dir(self, path, **kwargs):
         """
@@ -212,7 +212,7 @@ class PyWebHdfsClient(object):
         response = requests.put(uri, allow_redirects=True)
 
         if not response.status_code == httplib.OK:
-            _raise_pywebhdfs_exception(response.status_code, response.text)
+            _raise_pywebhdfs_exception(response.status_code, response.content)
 
         return True
 
@@ -241,7 +241,7 @@ class PyWebHdfsClient(object):
         response = requests.put(uri, allow_redirects=True)
 
         if not response.status_code == httplib.OK:
-            _raise_pywebhdfs_exception(response.status_code, response.text)
+            _raise_pywebhdfs_exception(response.status_code, response.content)
 
         return True
 
@@ -272,7 +272,7 @@ class PyWebHdfsClient(object):
         response = requests.delete(uri, allow_redirects=True)
 
         if not response.status_code == httplib.OK:
-            _raise_pywebhdfs_exception(response.status_code, response.text)
+            _raise_pywebhdfs_exception(response.status_code, response.content)
 
         return True
 
@@ -330,7 +330,7 @@ class PyWebHdfsClient(object):
         response = requests.get(uri, allow_redirects=True)
 
         if not response.status_code == httplib.OK:
-            _raise_pywebhdfs_exception(response.status_code, response.text)
+            _raise_pywebhdfs_exception(response.status_code, response.content)
 
         return response.json()
 
@@ -386,7 +386,7 @@ class PyWebHdfsClient(object):
         response = requests.get(uri, allow_redirects=True)
 
         if not response.status_code == httplib.OK:
-            _raise_pywebhdfs_exception(response.status_code, response.text)
+            _raise_pywebhdfs_exception(response.status_code, response.content)
 
         return response.json()
 
@@ -398,22 +398,22 @@ class PyWebHdfsClient(object):
 
         path_param = path
 
-        #setup the parameter represent the WebHDFS operation
+        # setup the parameter represent the WebHDFS operation
         operation_param = '?op={operation}'.format(operation=operation)
 
-        #configure authorization based on provided credentials
+        # configure authorization based on provided credentials
         auth_param = str()
         if self.user_name:
             auth_param = '&user.name={user_name}'.format(
                 user_name=self.user_name)
 
-        #setup any optional parameters
+        # setup any optional parameters
         keyword_params = str()
         for key in kwargs:
             keyword_params = '{params}&{key}={value}'.format(
                 params=keyword_params, key=key, value=str(kwargs[key]).lower())
 
-        #build the complete uri from the base uri and all configured params
+        # build the complete uri from the base uri and all configured params
         uri = '{base_uri}{path}{operation}{keyword_args}{auth}'.format(
             base_uri=self.base_uri, path=path_param,
             operation=operation_param, keyword_args=keyword_params,
